@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -82,7 +82,7 @@ sub generate {
         if (
             ($flavor =~ /5/ && $x eq $tones[4])
             ||
-            ($flavor =~ /7/ && $x eq $tones[6])
+            ($flavor =~ /7/ && $flavor !~ /M7/ && $x eq $tones[6])
             ||
             ($flavor =~ /[#b]9/ && $x eq $tones[1])
             ||
@@ -134,7 +134,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
